Index: recipes/pdfium.py |
diff --git a/recipes/v8.py b/recipes/pdfium.py |
similarity index 71% |
copy from recipes/v8.py |
copy to recipes/pdfium.py |
index b2270d024b516b9efa4e19031297979416c60a9f..35bf7b8a5270aaaa0b0b4a7d90117ea1ca625e78 100644 |
--- a/recipes/v8.py |
+++ b/recipes/pdfium.py |
@@ -1,4 +1,4 @@ |
-# Copyright 2014 The Chromium Authors. All rights reserved. |
+# Copyright 2015 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
@@ -9,14 +9,14 @@ import recipe_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class V8(recipe_util.Recipe): |
- """Basic Recipe class for V8.""" |
+class PDFium(recipe_util.Recipe): |
+ """Basic Recipe class for PDFium.""" |
@staticmethod |
def fetch_spec(props): |
- url = 'https://chromium.googlesource.com/v8/v8.git' |
+ url = 'https://pdfium.googlesource.com/pdfium.git' |
solution = { |
- 'name' : 'v8', |
+ 'name' : 'pdfium', |
'url' : url, |
'deps_file' : 'DEPS', |
'managed' : False, |
@@ -25,7 +25,6 @@ class V8(recipe_util.Recipe): |
} |
spec = { |
'solutions': [solution], |
- 'with_branch_heads': True, |
} |
return { |
'type': 'gclient_git', |
@@ -34,11 +33,11 @@ class V8(recipe_util.Recipe): |
@staticmethod |
def expected_root(_props): |
- return 'v8' |
+ return 'pdfium' |
def main(argv=None): |
- return V8().handle_args(argv) |
+ return PDFium().handle_args(argv) |
if __name__ == '__main__': |